//! ### Registers
//!
//! Registers are memory devices that will change their state only on a clock
//! edge (or when being reset). They retain their state when not connected to.
//!
//! Registers create a Rust variable with type [`Expr<T>`] where `T` is the type of the register.
//!
//! Registers follow [connection semantics], which are unlike assignments in software, so you should read it.
//!
//! ```
//! # use fayalite::{hdl_module, int::UInt, array::Array, clock::ClockDomain};
//! # #[hdl_module]
//! # fn module() {
//! # #[hdl]
//! # let v: UInt<1> = m.input();
//! #[hdl]
//! let cd: ClockDomain = m.input();
//! #[hdl]
//! let my_register: UInt<8> = m.reg_builder().clock_domain(cd).reset(8_hdl_u8);
//! #[hdl]
//! if v {
//!     // my_register is only changed when both `v` is set and `cd`'s clock edge occurs.
//!     m.connect(my_register, 0x45_hdl_u8);
//! }
//! # }
//! ```
//!
//! [connection semantics]: crate::_docs::semantics::connection_semantics

#[allow(unused)]
use crate::expr::Expr;
